import React from "react";
import {Table, Column} from "react-tisch";
import {Glyphicon, Label, Button, ButtonGroup} from "react-bootstrap";
import sampleData from "../../assets/sample_data";


const EyeColor = function ({eyeColor}) {
    return <Glyphicon glyph="eye-open" style={{color: eyeColor}}/>;
};


const Tags = function ({tags}) {
    return <div>{tags.map((tag, i) =>
        <Label bsStyle="default" key={i}>{tag}</Label>)}</div>;
};


class RadioButtonGroup extends React.Component {
    /** Component made up of two Bootstrap buttons that acts as radio buttons. The one difference between this
     * functionality and a normal set of radio button is that it also allows both buttons to be unselected. **/
    static propTypes = {
        btnOneText: React.PropTypes.string.isRequired,
        btnTwoText: React.PropTypes.string.isRequired,
        onChange: React.PropTypes.func.isRequired,
    };

    state = {
        btnOneActive: false,
        btnTwoActive: false
    };

    componentDidMount() {
        if (this.state.btnOneActive) {
            console.log('Active!!', this.props.btnOneText);
        } else {
            console.log('Creating', this.props.btnOneText);
        }
    }

    componentWillReceiveProps(nextProps) {
        console.log('Updating', nextProps.btnOneText);
    }

    handleClick(type) {
        console.log('Handle', type);
        switch (type) {
            case this.props.btnOneText:
                if (this.state.btnOneActive)
                    this.setState({btnOneActive: false});
                else
                    this.setState({btnOneActive: true, btnTwoActive: false});
                break;
            case this.props.btnTwoText:
                if (this.state.btnTwoActive)
                    this.setState({btnTwoActive: false});
                else
                    this.setState({btnOneActive: false, btnTwoActive: true});
                break;
        }

        //this.props.onChange(type);
    }

    render() {
        const {btnOneText, btnTwoText} = this.props;
        const {btnOneActive = false, btnTwoActive = false} = this.state;

        return (
            <ButtonGroup>
                State is {btnOneActive.toString()} {btnTwoActive.toString()}
                <Button active={btnOneActive}
                        bsStyle={btnOneActive ? 'primary' : 'default'}
                        onClick={() => this.handleClick(btnOneText)}>
                    {btnOneText}
                </Button>
                <Button active={btnTwoActive}
                        bsStyle={btnTwoActive ? 'primary' : 'default'}
                        onClick={() => this.handleClick(btnTwoText)}>
                    {btnTwoText}
                </Button>
            </ButtonGroup>
        )
    }
}


const Sample4 = () =>
    <Table data={sampleData}>
        <Column value={row => row.name}>Name</Column>
        <Column filter value={EyeColor} rawValue={row => row.eyeColor}>Eye color</Column>
        <Column value={Tags}>Tags</Column>
        <Column value={row => <RadioButtonGroup btnOneText={row.name} btnTwoText='no'>Hello</RadioButtonGroup>}></Column>
    </Table>;

export default Sample4;
